@@ -5,13 +5,13 @@ use strict;
 use warnings;
 
 
-our $VERSION = 'v0.201.2';
+our $VERSION = 'v0.202.0';
 
 
-use Role::Declare -lax;
+use Role::Declare -lax; # so missing named parameters default to undef
 
 use OpenTracing::Types qw/ContextReference Scope ScopeManager Span SpanContext/;
-use Types::Standard qw/Maybe Any ArrayRef Bool Dict HashRef Optional Str/;
+use Types::Standard qw/ArrayRef Bool Dict HashRef Maybe Object Str/;
 use Types::Common::Numeric qw/PositiveOrZeroNum/;
 
 use Carp;
@@ -19,6 +19,7 @@ use Carp;
 use namespace::clean;
 
 
+
 instance_method get_scope_manager(
 ) :Return(ScopeManager) {}
 
@@ -36,11 +37,11 @@ instance_method start_active_span(
     Maybe[ HashRef[Str] ]               :$tags,
     Maybe[ PositiveOrZeroNum ]          :$start_time,
     Maybe[ Bool ]                       :$ignore_active_span,
-    Maybe[ Bool ]                       :$finish_span_on_close, # should default to true
+    Maybe[ Bool ]                       :$finish_span_on_close,
 ) :Return(Scope) {
     croak "'child_of' and 'references' are mutual exclusive options"
         if defined $child_of && defined $references;
-};
+}
 
 
 
@@ -54,21 +55,21 @@ instance_method start_span(
 ) :Return(Span) {
     croak "'child_of' and 'references' are mutual exclusive options"
       if defined $child_of && defined $references;
-};
+}
 
 
 
 instance_method inject_context(
-    $carrier_format,
-    $carrier,
+    Str    $carrier_format,
+    Object $carrier,
     SpanContext $span_context
-) {}
+) :Return(Object) {}
 
 
 
 instance_method extract_context(
-    $carrier_format,
-    $carrier
+    Str    $carrier_format,
+    Object $carrier
 ) :ReturnMaybe(SpanContext) {}
 
 
